@@ -99,7 +99,7 @@ impl<'main> BatPrinter<'main> {
         let mut themes: Vec<_> = self.assets.themes().collect();
         themes.sort_unstable();
         for theme in themes.into_iter() {
-            println!("\x1b[1m{:?}\x1b[0m", theme);
+            println!("\x1b[1m{theme:?}\x1b[0m");
             self.config.theme = theme.to_string();
             self.print(sample.clone())?;
             println!();
