@@ -263,6 +263,14 @@ fn command() -> Command {
                     .action(ArgAction::SetTrue)
                     .help("Search hidden files and directories. By default, hidden files and directories are skipped"),
             )
+            .arg(
+                Arg::new("ignore-file")
+                    .long("ignore-file")
+                    .action(ArgAction::Append)
+                    .num_args(1)
+                    .value_name("PATH")
+                    .help("Specify a path to one or more gitignore formatted rules files. These patterns are applied after the patterns found in .gitignore, .rgignore and .ignore are applied and are matched relative to the current working directory"),
+            )
             .arg(
                 Arg::new("glob")
                     .short('g')
@@ -439,6 +447,17 @@ fn command() -> Command {
                     .value_parser(clap::builder::ValueParser::path_buf()),
             );
 
+    #[cfg(any(feature = "syntect-printer", feature = "ripgrep"))]
+    let cmd = cmd
+        .arg(
+            Arg::new("threads")
+                .short('j')
+                .long("threads")
+                .num_args(1)
+                .value_name("NUM")
+                .help("The approximate number of threads to use. A The default value causes ripgrep to choose the thread count using heuristics"),
+        );
+
     cmd
 }
 
@@ -496,6 +515,10 @@ fn build_ripgrep_config(
         config.globs(globs.map(String::as_str));
     }
 
+    if let Some(paths) = matches.get_many::<String>("ignore-file") {
+        config.ignore_files(paths.map(String::as_str));
+    }
+
     if let Some(num) = matches.get_one::<String>("max-count") {
         let num = num
             .parse()
@@ -601,6 +624,17 @@ fn run(matches: ArgMatches) -> Result<bool> {
         .context("Could not parse \"max-context\" option value as unsigned integer")?;
     let max_context = cmp::max(min_context, max_context);
 
+    #[cfg(any(feature = "syntect-printer", feature = "ripgrep"))]
+    if let Some(threads) = matches.get_one::<String>("threads") {
+        let threads = threads
+            .parse()
+            .context("Could not parse \"threads\" option value as unsigned integer")?;
+        rayon::ThreadPoolBuilder::new()
+            .num_threads(threads)
+            .build_global()
+            .with_context(|| format!("Could not prepare a thread pool with {threads} threads"))?;
+    }
+
     let mut printer_opts = PrinterOptions::default();
     if let Some(width) = matches.get_one::<String>("tab") {
         printer_opts.tab_width = width
@@ -773,17 +807,16 @@ fn run(matches: ArgMatches) -> Result<bool> {
 fn main() {
     #[cfg(windows)]
     if let Err(code) = nu_ansi_term::enable_ansi_support() {
-        eprintln!("ANSI color support could not be enabled with error code {code}");
-        process::exit(2);
+        panic!("ANSI color support could not be enabled with error code {code}");
     }
 
     let status = match Args::new().and_then(|a| run(command().get_matches_from(a))) {
         Ok(true) => 0,
         Ok(false) => 1,
         Err(err) => {
-            eprintln!("\x1b[1;91merror:\x1b[0m {}", err);
+            eprintln!("\x1b[1;91merror:\x1b[0m {err}");
             for err in err.chain().skip(1) {
-                eprintln!("  Caused by: {}", err);
+                eprintln!("  Caused by: {err}");
             }
             2
         }
@@ -867,6 +900,7 @@ mod tests {
         snapshot_test!(unrestricted_twice, ["-u", "-u"]);
         snapshot_test!(unrestricted_twice_in_single_flag, ["-uu"]);
         snapshot_test!(encoding, ["--encoding", "sjis"]);
+        snapshot_test!(threads, ["--threads", "4"]);
         snapshot_test!(
             all_printer_opts_before_args,
             [
@@ -968,6 +1002,7 @@ mod tests {
             bat_doesnt_support_ascii_lines,
             ["--printer", "bat", "--ascii-lines"]
         );
+        snapshot_error_test!(invalid_threads, ["--threads", "foo"]);
 
         #[test]
         fn arg_parser_debug_assert() {
@@ -983,7 +1018,7 @@ mod tests {
                 &["--generate-completion-script", "unknown-shell"][..],
             ] {
                 let parsed = command().try_get_matches_from(args);
-                assert!(parsed.is_err(), "args: {:?}", args);
+                assert!(parsed.is_err(), "args: {args:?}");
             }
         }
     }
@@ -1025,6 +1060,17 @@ mod tests {
             glob_many,
             ["-g", "*.txt", "-g", "*.rs", "-g", "*.md", "pat", "dir"]
         );
+        snapshot_test!(
+            ignore_file,
+            [
+                "--ignore-file",
+                "foo.ignore",
+                "--ignore-file",
+                "bar.ignore",
+                "pat",
+                "dir"
+            ]
+        );
         snapshot_test!(glob_before_opt, ["-g", "*.txt", "-i", "pat", "dir"]);
         snapshot_test!(glob_arg_with_hyphen, ["-g", "-foo_*.txt", "pat", "dir"]);
         snapshot_test!(ignore_case_smart_case, ["-i", "-S", "pat", "dir"]);
@@ -1115,7 +1161,7 @@ mod tests {
         for shell in COMPLETION_SHELLS {
             let mut v = vec![];
             generate_completion_script(shell, &mut v);
-            assert!(!v.is_empty(), "shell: {}", shell);
+            assert!(!v.is_empty(), "shell: {shell}");
         }
     }
 
@@ -1190,7 +1236,7 @@ mod tests {
             env::set_var(OPTS_ENV_VAR, "'-i");
 
             let err = Args::new().unwrap_err();
-            let msg = format!("{}", err);
+            let msg = format!("{err}");
             assert!(
                 msg.contains("cannot be parsed as a shell command"),
                 "{msg:?}",
@@ -1208,7 +1254,7 @@ mod tests {
             env::set_var(OPTS_ENV_VAR, OsStr::from_bytes(b"\xc3\x28"));
 
             let err = Args::new().unwrap_err();
-            let msg = format!("{}", err);
+            let msg = format!("{err}");
             assert!(msg.contains("is not a valid UTF-8 sequence"), "{msg:?}");
         }
     }
