@@ -36,7 +36,7 @@ fn parse_size(input: &str) -> Result<u64> {
 
     let u: u64 = input
         .parse()
-        .with_context(|| format!("Could not parse {:?} as unsigned integer", input))?;
+        .with_context(|| format!("Could not parse {input:?} as unsigned integer"))?;
 
     Ok(u * mag)
 }
@@ -47,6 +47,7 @@ pub struct Config<'main> {
     max_context: u64,
     no_ignore: bool,
     hidden: bool,
+    ignore_files: Box<[&'main Path]>,
     case_insensitive: bool,
     smart_case: bool,
     globs: Box<[&'main str]>,
@@ -95,6 +96,11 @@ impl<'main> Config<'main> {
         self
     }
 
+    pub fn ignore_files(&mut self, paths: impl Iterator<Item = &'main str>) -> &mut Self {
+        self.ignore_files = paths.map(Path::new).collect();
+        self
+    }
+
     pub fn hidden(&mut self, yes: bool) -> &mut Self {
         self.hidden = yes;
         self
@@ -268,6 +274,12 @@ impl<'main> Config<'main> {
 
         if !self.no_ignore {
             builder.add_custom_ignore_filename(".rgignore");
+
+            for path in self.ignore_files.iter().copied() {
+                if let Some(err) = builder.add_ignore(path) {
+                    return Err(err).context(format!("Could not read the ignore file {path:?}"));
+                }
+            }
         }
 
         Ok(builder.build())
@@ -304,11 +316,11 @@ impl<'main> Config<'main> {
         Ok(if self.fixed_strings {
             let mut s = regex_syntax::escape(pat);
             if self.line_regexp {
-                s = format!("^(?:{})$", s);
+                s = format!("^(?:{s})$");
             }
             builder.build(&s)?
         } else if self.line_regexp {
-            builder.build(&format!("^(?:{})$", pat))?
+            builder.build(&format!("^(?:{pat})$"))?
         } else {
             builder.build(pat)?
         })
@@ -339,7 +351,7 @@ impl<'main> Config<'main> {
         }
 
         if self.line_regexp {
-            Ok(builder.build(&format!("^(?:{})$", pat))?)
+            Ok(builder.build(&format!("^(?:{pat})$"))?)
         } else {
             Ok(builder.build(pat)?)
         }
@@ -348,7 +360,14 @@ impl<'main> Config<'main> {
     fn build_searcher(&self) -> Result<Searcher> {
         let mut builder = SearcherBuilder::new();
         let mmap = if self.mmap {
-            unsafe { MmapChoice::auto() }
+            // Safety: It is not possible to guarantee this configuration is safe on all platforms. However the worst
+            // case caused by this configuration is SIGBUS (the mapped file is truncated while reading) and it just
+            // makes hgrep abort.
+            // See: https://docs.rs/grep-searcher/latest/grep_searcher/struct.MmapChoice.html#method.auto
+            #[allow(unsafe_code)]
+            unsafe {
+                MmapChoice::auto()
+            }
         } else {
             MmapChoice::never()
         };
@@ -519,7 +538,7 @@ impl<M: Matcher> Sink for Matches<'_, M> {
                 ranges.push((m.start(), m.end()));
                 true
             })
-            .map_err(|e| io::Error::new(io::ErrorKind::Other, format!("{}", e)))?;
+            .map_err(|e| io::Error::other(format!("{e}")))?;
         let mut regions = LineRegions::new(&ranges);
 
         let mut line_number = line_number;
@@ -686,7 +705,7 @@ mod tests {
         for input in inputs.iter() {
             let mut printer = DummyPrinter::default();
             let pat = r"\*$";
-            let file = dir.join(format!("{}.in", input));
+            let file = dir.join(format!("{input}.in"));
             let paths = iter::once(file.as_path());
             let found = grep(&printer, pat, Some(paths), Config::new(3, 6)).unwrap();
             let expected = read_expected_chunks(&dir, input)
@@ -710,7 +729,7 @@ mod tests {
         let pat = r"\*$";
         let paths = inputs
             .iter()
-            .map(|s| dir.join(format!("{}.in", s)).into_os_string())
+            .map(|s| dir.join(format!("{s}.in")).into_os_string())
             .collect::<Vec<_>>();
         let paths = paths.iter().map(AsRef::as_ref);
 
@@ -736,8 +755,8 @@ mod tests {
         let pat = "^this does not match to any line!!!!!!$";
         let found = grep(&printer, pat, Some(paths), Config::new(3, 6)).unwrap();
         let files = printer.0.into_inner().unwrap();
-        assert!(!found, "result: {:?}", files);
-        assert!(files.is_empty(), "result: {:?}", files);
+        assert!(!found, "result: {files:?}");
+        assert!(files.is_empty(), "result: {files:?}");
     }
 
     #[test]
@@ -769,7 +788,7 @@ mod tests {
         let paths = iter::once(path.as_path());
         let pat = ".*";
         let err = grep(ErrorPrinter, pat, Some(paths), Config::new(3, 6)).unwrap_err();
-        let msg = format!("{}", err);
+        let msg = format!("{err}");
         assert_eq!(msg, "dummy error");
     }
 
@@ -782,7 +801,7 @@ mod tests {
 
         let re = Regex::new(r"^\x1b\[1m\w+\x1b\[0m: .+(, .+)*$").unwrap();
         for line in output.lines() {
-            assert!(re.is_match(line), "{:?} did not match to {:?}", line, re);
+            assert!(re.is_match(line), "{line:?} did not match to {re:?}");
         }
     }
 
@@ -796,8 +815,7 @@ mod tests {
             let chunks_line = lines.next().unwrap();
             assert!(
                 chunks_line.starts_with("# chunks: "),
-                "actual={:?}",
-                chunks_line
+                "actual={chunks_line:?}"
             );
             let chunks_line = &chunks_line["# chunks: ".len()..];
             for chunk in chunks_line.split(", ") {
@@ -813,8 +831,7 @@ mod tests {
             let matches_line = lines.next().unwrap();
             assert!(
                 matches_line.starts_with("# lines: "),
-                "actual={:?}",
-                matches_line
+                "actual={matches_line:?}"
             );
             let matches_line = &matches_line["# lines: ".len()..];
             for mat in matches_line.split(", ") {
@@ -842,7 +859,7 @@ mod tests {
         f(&mut config);
 
         let found = grep(&printer, pat, Some(paths), config).unwrap();
-        assert!(found, "file={}", file);
+        assert!(found, "file={file}");
 
         let mut files = printer.0.into_inner().unwrap();
         assert_eq!(files.len(), 1, "file={}", file);
@@ -1020,23 +1037,45 @@ mod tests {
                     ),
                     Err(want) => {
                         let err = err.unwrap_or_else(|| {
-                            panic!(
-                                "wanted error {:?} but no error for {:?} ({})",
-                                want, input, opt
-                            )
+                            panic!("wanted error {want:?} but no error for {input:?} ({opt})")
                         });
-                        let msg = format!("{}", err);
+                        let msg = format!("{err}");
                         assert!(
                             msg.contains(want),
-                            "wanted error {:?} but got {:?} for {:?} ({})",
-                            want,
-                            msg,
-                            input,
-                            opt,
+                            "wanted error {want:?} but got {msg:?} for {input:?} ({opt})",
                         );
                     }
                 }
             }
         }
     }
+
+    #[test]
+    fn test_ignore_file_ok() {
+        #[cfg(not(windows))]
+        let dir = Path::new("testdata/ripgrep/ignore_file");
+        #[cfg(windows)]
+        let dir = Path::new(r#"testdata\ripgrep\ignore_file"#);
+
+        let ignore = dir.join("test_ignore");
+        let mut config = Config::default();
+        config.ignore_files([ignore.to_str().unwrap()].into_iter());
+        let paths = iter::once(dir);
+        let printer = DummyPrinter::default();
+        let found = grep(&printer, "foo", Some(paths), config).unwrap();
+        assert!(!found, "Matched: {:?}", printer.0.lock().unwrap());
+    }
+
+    #[test]
+    fn test_ignore_file_file_not_found() {
+        let mut config = Config::default();
+        config.ignore_files(["this_does_not_exist"].into_iter());
+        let paths = iter::once(Path::new("testdata"));
+        let err = grep(&DummyPrinter::default(), "foo", Some(paths), config).unwrap_err();
+        let msg = format!("{err}");
+        assert!(
+            msg.contains("Could not read the ignore file"),
+            "Error message: {msg:?}",
+        );
+    }
 }
