@@ -70,7 +70,7 @@ fn list_themes_with_syntaxes<W: Write>(
         .try_for_each(|(name, theme)| -> Result<()> {
             let mut drawer = Drawer::new(&mut out, opts, theme, &sample_file.chunks);
             drawer.canvas.set_bold()?;
-            write!(drawer.canvas, "{:?}", name)?;
+            write!(drawer.canvas, "{name:?}")?;
             drawer.canvas.draw_newline()?;
             drawer.canvas.draw_sample()?;
             writeln!(drawer.canvas)?;
@@ -521,7 +521,7 @@ impl<W: Write> Canvas<W> {
 
     fn draw_sample_row(&mut self, colors: &[(&str, Color)]) -> io::Result<()> {
         for (name, color) in colors {
-            write!(self.out, "    {} ", name)?;
+            write!(self.out, "    {name} ")?;
             self.set_bg(*color)?;
             self.out.write_all(b"    \x1b[0m")?;
         }
@@ -675,7 +675,7 @@ impl<'file, W: Write> Drawer<'file, W> {
         let width = num_digits(lnum);
         self.canvas
             .draw_spaces((self.lnum_width - width) as usize)?;
-        write!(self.canvas, " {}", lnum)?;
+        write!(self.canvas, " {lnum}")?;
         if self.grid {
             if matched {
                 self.canvas.set_gutter_color()?;
@@ -795,7 +795,7 @@ impl<'file, W: Write> Drawer<'file, W> {
                         self.draw_text_wrappping(matched, events.current_style, events.in_region)?;
                         width = 0;
                     }
-                    write!(self.canvas, "{}", c)?;
+                    write!(self.canvas, "{c}")?;
                     width += w;
                 }
                 DrawEvent::TokenBoundary(prev_style) => {
@@ -880,7 +880,7 @@ impl<'file, W: Write> Drawer<'file, W> {
         let path = path.as_os_str().to_string_lossy();
         self.canvas.set_default_fg()?;
         self.canvas.set_bold()?;
-        write!(self.canvas, " {}", path)?;
+        write!(self.canvas, " {path}")?;
         if self.canvas.has_background {
             self.canvas
                 .fill_spaces(path.width_cjk() + 1, self.term_width as usize)?;
@@ -1013,6 +1013,8 @@ impl<'main, W> SyntectPrinter<'main, W> {
                 "sarif" | "jsonl" | "geojson" | "jsonc" | "jsonld" => Some("JSON"),
                 "ron" => Some("Rust"),
                 "mkd" => Some("Markdown"),
+                "mill" => Some("Scala"), // https://mill-build.org/mill/index.html
+                "flatpakref" | "flatpakrepo" => Some("INI"),
                 _ => None,
             })
             // Find from file name
@@ -1021,6 +1023,9 @@ impl<'main, W> SyntectPrinter<'main, W> {
                 "nginx.conf" | "mime.types" => Some("nginx"),
                 "httpd.conf" => Some("Apache Conf"),
                 "Containerfile" => Some("Dockerfile"),
+                "uv.lock" => Some("TOML"),
+                "paru.conf" => Some("INI"),
+                "flake.lock" => Some("JSON"),
                 _ => None,
             })
             // Find from file path
@@ -1055,29 +1060,33 @@ impl<'main, W> SyntectPrinter<'main, W> {
                 if path.ends_with(SSH_CONFIG) {
                     return Some("SSH Config");
                 }
+
                 #[cfg(not(windows))]
-                if path == "/etc/profile" {
-                    return Some("Bourne Again Shell (bash)");
-                }
-                #[cfg(not(windows))]
-                if path.starts_with("/var/spool/mail/") || path.starts_with("/var/mail/") {
-                    return Some("Email");
-                }
-                #[cfg(not(windows))]
-                if path.starts_with("/etc/wireguard/") && path.ends_with(".conf") {
-                    return Some("INI");
-                }
-                #[cfg(not(windows))]
-                if path == "/etc/pacman.conf" {
-                    return Some("INI");
-                }
-                #[cfg(not(windows))]
-                if path.contains("/containers/") && path.ends_with(".conf") {
-                    return Some("TOML");
-                }
-                #[cfg(not(windows))]
-                if path.starts_with("/etc/kubernetes/") && path.ends_with(".conf") {
-                    return Some("YAML");
+                {
+                    if path == "/etc/profile" {
+                        return Some("Bourne Again Shell (bash)");
+                    }
+                    if path.starts_with("/var/spool/mail/") || path.starts_with("/var/mail/") {
+                        return Some("Email");
+                    }
+                    if path.starts_with("/etc/wireguard/") && path.ends_with(".conf") {
+                        return Some("INI");
+                    }
+                    if path == "/etc/pacman.conf" {
+                        return Some("INI");
+                    }
+                    if path.contains("/containers/") && path.ends_with(".conf") {
+                        return Some("TOML");
+                    }
+                    if path.starts_with("/etc/kubernetes/") && path.ends_with(".conf") {
+                        return Some("YAML");
+                    }
+                    if path.starts_with("/etc/letsencrypt/renewal/") && path.ends_with(".conf") {
+                        return Some("INI");
+                    }
+                    if path == "/var/log/dmesg" {
+                        return Some("Syslog");
+                    }
                 }
                 None
             });
@@ -1117,15 +1126,15 @@ impl<W: WriteOnLocked> Printer for SyntectPrinter<'_, W> {
 mod tests {
     use super::*;
     use crate::chunk::{File, LineMatch};
-    use once_cell::sync::Lazy;
     use std::cell::{RefCell, RefMut};
     use std::fmt;
     use std::fs;
     use std::mem;
     use std::path::PathBuf;
     use std::str;
+    use std::sync::LazyLock;
 
-    static ASSETS: Lazy<SyntectAssets> = Lazy::new(|| SyntectAssets::load(None).unwrap());
+    static ASSETS: LazyLock<SyntectAssets> = LazyLock::new(|| SyntectAssets::load(None).unwrap());
 
     struct DummyStdoutLock<'a>(RefMut<'a, Vec<u8>>);
     impl Write for DummyStdoutLock<'_> {
@@ -1272,8 +1281,8 @@ mod tests {
             if input.starts_with("test_") {
                 input = &input["test_".len()..];
             }
-            let infile = dir.join(format!("{}.rs", input));
-            let outfile = dir.join(format!("{}.out", input));
+            let infile = dir.join(format!("{input}.rs"));
+            let outfile = dir.join(format!("{input}.out"));
             let file = read_chunks(infile);
             run_uitest(file, outfile, f);
         }
@@ -1435,7 +1444,7 @@ mod tests {
             if input.starts_with("test_") {
                 input = &input["test_".len()..];
             }
-            let file = format!("list_themes_{}.out", input);
+            let file = format!("list_themes_{input}.out");
             let expected = Path::new("testdata").join("syntect").join(file);
             let expected = fs::read(expected).unwrap();
 
@@ -1522,7 +1531,7 @@ mod tests {
         let printer =
             SyntectPrinter::with_assets(ASSETS.clone(), ErrorStdout(io::ErrorKind::Other), opts);
         let err = printer.print(file).unwrap_err();
-        assert_eq!(&format!("{}", err), "dummy error!", "message={}", err);
+        assert_eq!(&format!("{err}"), "dummy error!", "message={err}");
     }
 
     #[test]
@@ -1547,8 +1556,8 @@ mod tests {
             Err(e) => e,
             Ok(_) => panic!("error did not occur"),
         };
-        let msg = format!("{}", err);
-        assert!(msg.contains("Unknown theme"), "message={:?}", msg);
+        let msg = format!("{err}");
+        assert!(msg.contains("Unknown theme"), "message={msg:?}");
     }
 
     #[test]
@@ -1626,7 +1635,7 @@ mod tests {
             &ASSETS.syntax_set,
         )
         .unwrap_err();
-        assert_eq!(&format!("{}", err), "dummy error!", "message={}", err);
+        assert_eq!(&format!("{err}"), "dummy error!", "message={err}");
     }
 
     #[test]
